"""
Python module generated from Java source file org.bukkit.inventory.CartographyInventory

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.inventory import *
from typing import Any, Callable, Iterable, Tuple


class CartographyInventory(Inventory):
    """
    Interface to the inventory of a Cartography table.
    """


