"""
Python module generated from Java source file com.google.common.collect.Hashing

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from com.google.common.primitives import Ints
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class Hashing:
    """
    Static methods for implementing hash-based collections.

    Author(s)
    - Austin Appleby
    """


