"""
Python module generated from Java source file com.google.common.base.CommonMatcher

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import *
from typing import Any, Callable, Iterable, Tuple


class CommonMatcher:
    """
    The subset of the java.util.regex.Matcher API which is used by this package, and also
    shared with the `re2j` library. For internal use only. Please refer to the `Matcher`
    javadoc for details.
    """

    def matches(self) -> bool:
        ...


    def find(self) -> bool:
        ...


    def find(self, index: int) -> bool:
        ...


    def replaceAll(self, replacement: str) -> str:
        ...


    def end(self) -> int:
        ...


    def start(self) -> int:
        ...
