"""
Python module generated from Java source file com.google.common.math.DoubleUtils

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.math import *
from java.math import BigInteger
from typing import Any, Callable, Iterable, Tuple


class DoubleUtils:
    """
    Utilities for `double` primitives.

    Author(s)
    - Louis Wasserman
    """


